##  Introduction
The export and import functionality for transformations allows you to add, update, and delete transformation items in bulk through an Excel spreadsheet.
For organizations dealing with large sets of transformations and where some collaborators on transformations are only occasional users of SAP LeanIX, this functionality makes it easier to handle and maintain transformation data.
